@@ -114,13 +114,13 @@ class ErrorSyntaxIgnored : public ErrorBase {
 		int ret() { return RET_SYNERR; }
 };
 
-void	PrintErrorCommand(char *buf)
+void	PrintErrorCommand(const char *buf)
 {
 	gtout(cerr, _("        %$     Command ignored\n"))
 	     << dump_bytes(buf, 0, strlen(buf), strlen(buf));
 }
 
-void	PrintErrorMessage(const char *msg, const char *cmd, char *buf)
+void	PrintErrorMessage(const char *msg, const char *cmd, const char *buf)
 {
 	cout << flush;
 	gtout(cerr, _("%$: %$ in `%$\' command:\n"))
@@ -129,52 +129,52 @@ void	PrintErrorMessage(const char *msg, const char *cmd, char *buf)
 	throw ErrorSyntaxIgnored();
 }
 
-void	ExtraChar(const char *cmd, char *buf)
+void	ExtraChar(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("extra characters"), cmd, buf);
 }
 
-void	InvalidValue(const char *cmd, char *buf)
+void	InvalidValue(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("invalid value"), cmd, buf);
 }
 
-void	InvalidAttr(const char *cmd, char *buf)
+void	InvalidAttr(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("invalid attribute"), cmd, buf);
 }
 
-void	InvalidColor(const char *cmd, char *buf)
+void	InvalidColor(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("invalid color"), cmd, buf);
 }
 
-void	MissingOn(const char *cmd, char *buf)
+void	MissingOn(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("ON required"), cmd, buf);
 }
 
-void	EqualNotFound(const char *cmd, char *buf)
+void	EqualNotFound(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("`=\' required"), cmd, buf);
 }
 
-void	QuoteNotFound(const char *cmd, char *buf)
+void	QuoteNotFound(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("`\"\' required"), cmd, buf);
 }
 
-void	YesNoNotFound(const char *cmd, char *buf)
+void	YesNoNotFound(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("only YES or NO is allowed"), cmd, buf);
 }
 
-void	NumberRequired(const char *cmd, char *buf)
+void	NumberRequired(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("non-negative integer required"), cmd, buf);
 }
 
-void	BlankEntry(const char *cmd, char *buf)
+void	BlankEntry(const char *cmd, const char *buf)
 {
 	PrintErrorMessage(_("blank entry encountered"), cmd, buf);
 }
@@ -184,7 +184,7 @@ void	BlankEntry(const char *cmd, char *buf)
 *************************************************************************/
 
 // Return true - Yes, false - No
-bool	IsYesNo(const char *cmd, char *buf, int from, int len)
+bool	IsYesNo(const char *cmd, char *buf, size_t from, size_t len)
 {
 	if (CompareStringCase(buf+from, "yes", 3) == 0) {
 		if (!IsEmpty(buf, from+3, len))
@@ -205,7 +205,7 @@ bool	IsYesNo(const char *cmd, char *buf, int from, int len)
 
 // Read unsigned number till end of line
 // Return >=0 - OK, -1 Error
-unsigned	ReadUnsigned(const char *cmd, char *buf, int from, int len)
+unsigned	ReadUnsigned(const char *cmd, char *buf, size_t from, size_t len)
 {
 			// FIXME: Use size_t here
 	int	value = 0;
@@ -227,6 +227,28 @@ unsigned	ReadUnsigned(const char *cmd, char *buf, int from, int len)
 	return value;
 }
 
+size_t	SeekPastEqualSignOrThrow(const char *cmd, const char *buf, size_t from, size_t len)
+{
+	try {
+		from = SeekPastEqualSign(buf, from, len);
+	}
+	catch (...) {
+		EqualNotFound(cmd, buf);
+	}
+	return from;
+}
+
+size_t	SeekEndQuoteOrThrow(const char *cmd, const char *buf, size_t from, size_t len)
+{
+	try {
+		from = SeekChar('\"', buf, from, len, 2);
+	}
+	catch (...) {
+		QuoteNotFound(cmd, buf);
+	}
+	return from;
+}
+
 /*************************************************************************
 	Find string from linked-list
 *************************************************************************/
@@ -257,12 +279,10 @@ struct	ConfigValue {
 	Command processing/printing functions - Yes/No.
 *************************************************************************/
 
-void	ConfigYesNo(const char *cmd, char *buf, int from, int len,
+void	ConfigYesNo(const char *cmd, char *buf, size_t from, size_t len,
 		    const ConfigValue &cfg)
 {
-	from = SeekPastEqualSign(buf, from, len);
-	if (from < 0)
-		EqualNotFound(cmd, buf);
+	from = SeekPastEqualSignOrThrow(cmd, buf, from, len);
 
 	bool	yn = IsYesNo(cmd, buf, from, len);
 			// Note: error has already been reported by IsYesNo
@@ -283,12 +303,10 @@ void	PrintYesNo(const char *cmd, const ConfigValue &cfg)
 	Command processing/printing functions - Unsigned integer.
 *************************************************************************/
 
-void	ConfigUnsigned(const char *cmd, char *buf, int from, int len,
+void	ConfigUnsigned(const char *cmd, char *buf, size_t from, size_t len,
 		       const ConfigValue &cfg)
 {
-	from = SeekPastEqualSign(buf, from, len);
-	if (from < 0)
-		EqualNotFound(cmd, buf);
+	from = SeekPastEqualSignOrThrow(cmd, buf, from, len);
 
 	int	thres = ReadUnsigned(cmd, buf, from, len);
 			// Note: error has already been reported
@@ -305,21 +323,17 @@ void	PrintUnsigned(const char *cmd, const ConfigValue &cfg)
 	Command processing/printing functions - String list.
 *************************************************************************/
 
-void	ConfigStringList(const char *cmd, char *buf, int from, int len, 
+void	ConfigStringList(const char *cmd, char *buf, size_t from, size_t len, 
 			 const ConfigValue &cfg)
 {
-	from = SeekPastEqualSign(buf, from, len);
-	if (from < 0)
-		EqualNotFound(cmd, buf);
+	from = SeekPastEqualSignOrThrow(cmd, buf, from, len);
 
 	if (buf[from] != '\"')
 		QuoteNotFound(cmd, buf);
 	from++;
 
 					// Shell-style quote seek
-	int end_quote = SeekChar('\"', buf, from, len, 2);
-	if (end_quote < 0)
-		QuoteNotFound(cmd, buf);
+	size_t end_quote = SeekEndQuoteOrThrow(cmd, buf, from, len);
 
 	if (!IsEmpty(buf, end_quote+1, len))
 		ExtraChar(cmd, buf);
@@ -380,12 +394,12 @@ void	PrintStringList(const char *cmd, const ConfigValue &cfg)
 	cout << cmd << ": ";
 
 	bool	indent = false;
-	int	num_indent = strlen(cmd)+2;
+	size_t	num_indent = strlen(cmd)+2;
 
 	for (DirList::iterator iter = (*cfg.cfgStringListPtr)->begin(); 
 	     iter != (*cfg.cfgStringListPtr)->end(); ++iter) {
 		if (indent) {
-			for (int i = 0; i < num_indent; ++i)
+			for (size_t i = 0; i < num_indent; ++i)
 				cout << ' ';
 		}
 		else
@@ -411,12 +425,10 @@ void	PrintStringList(const char *cmd, const ConfigValue &cfg)
 	Command processing/printing functions - Clear string list.
 *************************************************************************/
 
-void	ConfigClearStringList(const char *cmd, char *buf, int from, int len, 
+void	ConfigClearStringList(const char *cmd, char *buf, size_t from, size_t len, 
 			      const ConfigValue &cfg)
 {
-	from = SeekPastEqualSign(buf, from, len);
-	if (from < 0)
-		EqualNotFound(cmd, buf);
+	from = SeekPastEqualSignOrThrow(cmd, buf, from, len);
 
 	if (CompareStringCase("all", buf+from, 3)) {
 
@@ -427,9 +439,7 @@ void	ConfigClearStringList(const char *cmd, char *buf, int from, int len,
 		from++;
 
 					// Shell-style quote seek
-		int end_quote = SeekChar('\"', buf, from, len, 2);
-		if (end_quote < 0)
-			QuoteNotFound(cmd, buf);
+		size_t end_quote = SeekEndQuoteOrThrow(cmd, buf, from, len);
 
 		if (!IsEmpty(buf, end_quote+1, len))
 			ExtraChar(cmd, buf);
@@ -496,12 +506,10 @@ AttrColorMap colorMap[NUM_COLOR] = {
 	{ "default", DEFAULT_COLOR }
 };
 
-void	ConfigColorAttr(const char *cmd, char *buf, int from, int len, 
+void	ConfigColorAttr(const char *cmd, char *buf, size_t from, size_t len, 
 			const ConfigValue &cfg)
 {
-	from = SeekPastEqualSign(buf, from, len);
-	if (from < 0)
-		EqualNotFound(cmd, buf);
+	from = SeekPastEqualSignOrThrow(cmd, buf, from, len);
 
 	bool first_attr = true;
 	bool found_normal = false;
@@ -512,7 +520,7 @@ void	ConfigColorAttr(const char *cmd, char *buf, int from, int len,
 	for ( ; ; ) {
 		tok_end = SeekConfigTokenEnd(buf, from, len);
 		for (i = 0; i < NUM_ATTR; ++i) {
-			int attr_len = strlen(attrMap[i].name);
+			size_t attr_len = strlen(attrMap[i].name);
 			if (tok_end-from == attr_len 
 			    && CompareStringCase(attrMap[i].name, buf+from, attr_len) == 0) {
 
@@ -547,7 +555,7 @@ void	ConfigColorAttr(const char *cmd, char *buf, int from, int len,
 
 	tok_end = SeekConfigTokenEnd(buf, from, len);
 	for (i = 0; i < NUM_COLOR; ++i) {
-		int color_len = strlen(colorMap[i].name);
+		size_t color_len = strlen(colorMap[i].name);
 		if (tok_end-from == color_len 
 		    && CompareStringCase(colorMap[i].name, buf+from, color_len) == 0) {
 
@@ -561,7 +569,7 @@ void	ConfigColorAttr(const char *cmd, char *buf, int from, int len,
 
 	from = tok_end;
 	from = SeekNonSpace(buf, from, len);
-	if (from < 0)
+	if (from == len)
 		InvalidValue(cmd, buf);
 
 	if (CompareStringCase("on", buf+from, 2))
@@ -569,12 +577,12 @@ void	ConfigColorAttr(const char *cmd, char *buf, int from, int len,
 	from += 2;
 
 	from = SeekNonSpace(buf, from, len);
-	if (from < 0)
+	if (from == len)
 		InvalidValue(cmd, buf);
 
 	tok_end = SeekConfigTokenEnd(buf, from, len);
 	for (i = 0; i < NUM_COLOR; ++i) {
-		int color_len = strlen(colorMap[i].name);
+		size_t color_len = strlen(colorMap[i].name);
 		if (tok_end-from == color_len 
 		    && CompareStringCase(colorMap[i].name, buf+from, color_len) == 0) {
 
@@ -586,7 +594,7 @@ void	ConfigColorAttr(const char *cmd, char *buf, int from, int len,
 		InvalidColor(cmd, buf);
 	from = tok_end;
 	from = SeekNonSpace(buf, from, len);
-	if (from != -1)
+	if (from != len)
 		ExtraChar(cmd, buf);
 
 	cfg.cfgAttrPtr->colorAttr = colorAttr;
@@ -594,19 +602,17 @@ void	ConfigColorAttr(const char *cmd, char *buf, int from, int len,
 	cfg.cfgAttrPtr->colorBackground = colorBackground;
 }
 
-void	ConfigColor(const char *cmd, char *buf, int from, int len, 
+void	ConfigColor(const char *cmd, char *buf, size_t from, size_t len, 
 		    const ConfigValue &cfg)
 {
-	from = SeekPastEqualSign(buf, from, len);
-	if (from < 0)
-		EqualNotFound(cmd, buf);
+	from = SeekPastEqualSignOrThrow(cmd, buf, from, len);
 
 	int color = COLOR_BLACK;		// Avoid compiler warning
 	int i, tok_end;
 
 	tok_end = SeekConfigTokenEnd(buf, from, len);
 	for (i = 0; i < NUM_COLOR; ++i) {
-		int color_len = strlen(colorMap[i].name);
+		size_t color_len = strlen(colorMap[i].name);
 		if (tok_end-from == color_len 
 		    && CompareStringCase(colorMap[i].name, buf+from, color_len) == 0) {
 
@@ -620,18 +626,16 @@ void	ConfigColor(const char *cmd, char *buf, int from, int len,
 
 	from = tok_end;
 	from = SeekNonSpace(buf, from, len);
-	if (from != -1)
+	if (from != len)
 		ExtraChar(cmd, buf);
 
 	*cfg.cfgIntPtr = color;
 }
 
-void	ConfigBWAttr(const char *cmd, char *buf, int from, int len, 
+void	ConfigBWAttr(const char *cmd, char *buf, size_t from, size_t len, 
 		     const ConfigValue &cfg)
 {
-	from = SeekPastEqualSign(buf, from, len);
-	if (from < 0)
-		EqualNotFound(cmd, buf);
+	from = SeekPastEqualSignOrThrow(cmd, buf, from, len);
 
 	bool first_attr = true;
 	bool found_normal = false;
@@ -640,7 +644,7 @@ void	ConfigBWAttr(const char *cmd, char *buf, int from, int len,
 		int tok_end = SeekConfigTokenEnd(buf, from, len);
 		int i;
 		for (i = 0; i < NUM_ATTR; ++i) {
-			int attr_len = strlen(attrMap[i].name);
+			size_t attr_len = strlen(attrMap[i].name);
 			if (tok_end-from == attr_len 
 			    && CompareStringCase(attrMap[i].name, buf+from, attr_len) == 0) {
 
@@ -664,7 +668,7 @@ void	ConfigBWAttr(const char *cmd, char *buf, int from, int len,
 
 		from = tok_end;
 		from = SeekNonSpace(buf, from, len);
-		if (from < 0) {			// No more attribute
+		if (from == len) {		// No more attribute
 			cfg.cfgAttrPtr->bwAttr = bwAttr;
 			return;
 		}
@@ -732,7 +736,7 @@ void	PrintBWAttr(const char *cmd, const ConfigValue &cfg)
 *************************************************************************/
 
 struct	ConfigFunc {
-	void	(*cfgReadFunc)(const char *cmd, char *buf, int from, int len, const ConfigValue &cfg);
+	void	(*cfgReadFunc)(const char *cmd, char *buf, size_t from, size_t len, const ConfigValue &cfg);
 	void	(*cfgPrintFunc)(const char *cmd, const ConfigValue &cfg);
 };
 
@@ -819,7 +823,7 @@ void	LoadConfig(const string &confFile, int quiet, bool checkSecure = false)
 {
 	FILE	*file;
 	int	ret = 0;		// OK
-	int	configLen;
+	size_t	configLen;
 	int	numError = 0;
 
 	Buffer	configLineBuf(true, 100);	// 100 = "Good" initial size
@@ -873,8 +877,8 @@ void	LoadConfig(const string &confFile, int quiet, bool checkSecure = false)
 		
 			if (configLen > 0) {	// Non empty/non comment line
 			
-				int i = SeekNonSpace(configLine, 0, configLen);
-				if (i < 0)		// Blank line
+				size_t i = SeekNonSpace(configLine, 0, configLen);
+				if (i == configLen)	// Blank line
 					continue;	// Check for EOF and 
 							// read another line
 					
@@ -882,7 +886,7 @@ void	LoadConfig(const string &confFile, int quiet, bool checkSecure = false)
 
 				for (k = 0; k < NUM_CONFIG_INFO; k++) {
 					const char	*cfgName = configInfo[k].cfgName;
-					int	cfgNameLen = strlen(cfgName);
+					size_t	cfgNameLen = strlen(cfgName);
 				
 					if (CompareStringCase(cfgName, configLine+i, cfgNameLen) == 0) {
 						i += cfgNameLen;
